@@ -148,7 +148,7 @@ def create_jwt(user, session_key, expires=None):
     if CALLABLE:
         fields.update(CALLABLE(user))
 
-    return jwt.encode(fields, KEY, algorithm=ALGO).decode('utf8')
+    return jwt.encode(fields, KEY, algorithm=ALGO)
 
 
 def convert_cookie(cookies, user):
